@@ -1,5 +1,4 @@
-pub mod handle;
-use self::handle::NSTDOSWindowsIOHandle;
+//! Windows standard IO.
 use crate::{
     core::{
         def::{NSTDChar, NSTDErrorCode},
@@ -11,13 +10,16 @@ use windows_sys::Win32::{
     Globalization::CP_UTF8,
     System::Console::{
         GetStdHandle, ReadConsoleA, SetConsoleOutputCP, WriteConsoleA, CONSOLE_READCONSOLE_CONTROL,
-        STD_INPUT_HANDLE, STD_OUTPUT_HANDLE,
+        STD_ERROR_HANDLE, STD_INPUT_HANDLE, STD_OUTPUT_HANDLE,
     },
 };
 
 /// Initializes the `nstd.os.windows.io` module. This function should be called before any others in
 /// this module.
-/// Returns: `NSTDErrorCode errc` - Nonzero on error.
+///
+/// # Returns
+///
+/// `NSTDErrorCode errc` - Nonzero on error.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
 pub unsafe extern "C" fn nstd_os_windows_io_init() -> NSTDErrorCode {
@@ -25,24 +27,35 @@ pub unsafe extern "C" fn nstd_os_windows_io_init() -> NSTDErrorCode {
 }
 
 /// Writes a C string to stdout.
-/// Parameters:
-///     `const NSTDOSWindowsIOHandle stream` - An IO stream.
-///     `const NSTDChar *const cstr` - The C string to write to stdout.
-/// Returns: `NSTDErrorCode errc` - Nonzero on error.
+///
+/// # Parameters
+///
+/// - `const NSTDOSWindowsHandle stream` - An IO stream.
+///
+/// - `const NSTDChar *const cstr` - The C string to write to stdout.
+///
+/// # Returns
+///
+/// `NSTDErrorCode errc` - Nonzero on error.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
 pub unsafe extern "C" fn nstd_os_windows_io_print(
-    stream: NSTDOSWindowsIOHandle,
+    stream: NSTDOSWindowsHandle,
     cstr: *const NSTDChar,
 ) -> NSTDErrorCode {
     let bytes = crate::core::cstr::nstd_core_cstr_as_slice(cstr);
-    nstd_os_windows_io_write(GetStdHandle(stream), &bytes, std::ptr::null_mut())
+    nstd_os_windows_io_write(stream, &bytes, std::ptr::null_mut())
 }
 
 /// Writes a C string to stdout with a newline character.
-/// Parameters:
-///     `const NSTDChar *const cstr` - The C string to write to stdout.
-/// Returns: `NSTDErrorCode errc` - Nonzero on error.
+///
+/// # Parameters
+///
+/// - `const NSTDChar *const cstr` - The C string to write to stdout.
+///
+/// # Returns
+///
+/// `NSTDErrorCode errc` - Nonzero on error.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
 pub unsafe extern "C" fn nstd_os_windows_io_print_line(cstr: *const NSTDChar) -> NSTDErrorCode {
@@ -58,27 +71,51 @@ pub unsafe extern "C" fn nstd_os_windows_io_print_line(cstr: *const NSTDChar) ->
 }
 
 /// Retrieves a handle to stdin.
-/// Returns: `NSTDOSWindowsIOHandle stdin` - The standard input stream.
+///
+/// # Returns
+///
+/// `NSTDOSWindowsHandle stdin` - The standard input stream.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_os_windows_io_stdin() -> NSTDOSWindowsIOHandle {
-    STD_INPUT_HANDLE
+pub unsafe extern "C" fn nstd_os_windows_io_stdin() -> NSTDOSWindowsHandle {
+    GetStdHandle(STD_INPUT_HANDLE)
 }
 
 /// Retrieves a handle to stdout.
-/// Returns: `NSTDOSWindowsIOHandle stdout` - The standard output stream.
+///
+/// # Returns
+///
+/// `NSTDOSWindowsHandle stdout` - The standard output stream.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_os_windows_io_stdout() -> NSTDOSWindowsIOHandle {
-    STD_OUTPUT_HANDLE
+pub unsafe extern "C" fn nstd_os_windows_io_stdout() -> NSTDOSWindowsHandle {
+    GetStdHandle(STD_OUTPUT_HANDLE)
+}
+
+/// Retrieves a handle to stderr.
+///
+/// # Returns
+///
+/// `NSTDOSWindowsHandle stderr` - The standard error stream.
+#[inline]
+#[cfg_attr(feature = "clib", no_mangle)]
+pub unsafe extern "C" fn nstd_os_windows_io_stderr() -> NSTDOSWindowsHandle {
+    GetStdHandle(STD_ERROR_HANDLE)
 }
 
 /// Reads a buffer from `stream` into `buffer`.
-/// Parameters:
-///     `const NSTDOSWindowsHandle stream` - Handle to an IO stream.
-///     `NSTDSlice *const buffer` - The buffer to read into.
-///     `NSTDUInt32 *const read` - Returns as the number of bytes actually read.
-/// Returns: `NSTDErrorCode errc` - Nonzero on error.
+///
+/// # Parameters
+///
+/// - `const NSTDOSWindowsHandle stream` - Handle to an IO stream.
+///
+/// - `NSTDSlice *const buffer` - The buffer to read into.
+///
+/// - `NSTDUInt32 *const read` - Returns as the number of bytes actually read.
+///
+/// # Returns
+///
+/// `NSTDErrorCode errc` - Nonzero on error.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
 pub unsafe extern "C" fn nstd_os_windows_io_read(
@@ -96,11 +133,18 @@ pub unsafe extern "C" fn nstd_os_windows_io_read(
 }
 
 /// Writes a buffer of `bytes` to `stream`.
-/// Parameters:
-///     `const NSTDOSWindowsHandle stream` - Handle to an IO stream.
-///     `const NSTDSlice *const bytes` - The bytes to write to the stream.
-///     `NSTDUInt32 *const written` - Returns as the number of bytes actually written.
-/// Returns: `NSTDErrorCode errc` - Nonzero on error.
+///
+/// # Parameters
+///
+/// - `const NSTDOSWindowsHandle stream` - Handle to an IO stream.
+///
+/// - `const NSTDSlice *const bytes` - The bytes to write to the stream.
+///
+/// - `NSTDUInt32 *const written` - Returns as the number of bytes actually written.
+///
+/// # Returns
+///
+/// `NSTDErrorCode errc` - Nonzero on error.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
 pub unsafe extern "C" fn nstd_os_windows_io_write(
